@@ -1,11 +1,10 @@
-from abc import ABC, abstractmethod, abstractproperty
-from typing import List, Type
+from abc import ABC, abstractmethod
+from typing import List
 
 import pandas as pd
 import matplotlib.pyplot as plt
 
 from magnumapi.geometry.Area import Area
-from magnumapi.geometry.roxie.BlockDefinition import BlockDefinition
 from magnumapi.geometry.roxie.CableDefinition import CableDefinition
 from magnumapi.geometry.roxie.ConductorDefinition import ConductorDefinition
 from magnumapi.geometry.roxie.InsulationDefinition import InsulationDefinition
@@ -34,6 +33,7 @@ class Block(ABC):
         self.insul_def = insul_def
         self.strand_def = strand_def
         self.conductor_def = conductor_def
+        self.block_def: Block = None
         self.areas: List[Area] = []
 
     @abstractmethod
@@ -52,6 +52,12 @@ class Block(ABC):
         """
         raise NotImplementedError('This method is not implemented for this class')
 
+    def empty_areas(self) -> None:
+        """ Method setting areas to an empty array
+
+        """
+        self.areas = []
+
     def get_bare_areas(self) -> List[Area]:
         """ Method returning bare areas, i.e., areas without insulation
 
