@@ -4,7 +4,7 @@ import datetime
 import plotly.graph_objects as go
 import plotly.express as px
 
-from magnumapi.geometry.CosThetaBlock import RelativeCosThetaBlock, HomogenizedCosThetaBlock
+from magnumapi.geometry.CosThetaBlock import RelativeCosThetaBlock, HomogenizedCosThetaBlock, CosThetaBlock
 from magnumapi.geometry.Geometry import Geometry
 from magnumapi.geometry.Arc import Arc
 from magnumapi.geometry.Line import Line
