@@ -9,6 +9,7 @@ import matplotlib.pyplot as plt
 
 from magnumapi.geometry.Area import Area
 from magnumapi.geometry.Block import Block
+from magnumapi.geometry.CosThetaBlock import CosThetaBlock
 from magnumapi.geometry.Line import Line
 
 
@@ -183,7 +184,7 @@ class Geometry(ABC):
         radius_prev = None
         for index, block in enumerate(self.blocks):
             # ToDo Fixed once layers are implemented
-            if radius_prev == block.block_def.radius:
+            if isinstance(block, CosThetaBlock) and radius_prev == block.block_def.radius:
                 area_curr = block.areas[0]
                 area_prev = self.blocks[index - 1].areas[-1]
 
@@ -198,6 +199,57 @@ class Geometry(ABC):
 
         return False
 
+    def correct_radiality(self) -> None:
+        """ Method correcting radiality of cos-theta blocks in a geometry.
+
+        """
+        # Set alpha equal to phi for all blocks except the mid-plane
+        self._set_alpha_equal_to_phi()
+
+        # Build blocks and calculate turn positions
+        self.build_blocks()
+
+        # Calculate alpha corrections
+        alpha_corrections = self._calculate_alpha_corrections()
+
+        # Correct alpha
+        self._apply_alpha_correction(alpha_corrections)
+
+        # Empty areas to return to the starting conditions
+        self._empty_areas()
+
+    def _set_alpha_equal_to_phi(self):
+        radius_prev = None
+        for index, block in enumerate(self.blocks):
+            if isinstance(block, CosThetaBlock) and radius_prev == block.block_def.radius:
+                block.block_def.alpha = block.block_def.phi
+
+            radius_prev = block.block_def.radius
+
+    def _calculate_alpha_corrections(self):
+        alpha_corrections = []
+        radius_prev = None
+        for index, block in enumerate(self.blocks):
+            # ToDo Fixed once layers are implemented
+            if isinstance(block, CosThetaBlock) and radius_prev == block.block_def.radius:
+                alpha_correction = CosThetaBlock.calculate_radiality_alpha_correction(block)
+            else:
+                alpha_correction = 0.0
+            alpha_corrections.append(alpha_correction)
+
+            radius_prev = block.block_def.radius
+
+        return alpha_corrections
+
+    def _apply_alpha_correction(self, alpha_corrections):
+        for index, block in enumerate(self.blocks):
+            if isinstance(block, CosThetaBlock):
+                block.block_def.alpha += alpha_corrections[index]
+
+    def _empty_areas(self):
+        for block in self.blocks:
+            block.empty_areas()
+
     @staticmethod
     def display_definition_table(df: pd.DataFrame) -> Grid:
         """ Static method displaying a definition table in an editable format in a notebook
