@@ -59,11 +59,7 @@ class RectangularBlock(Block):
             p3 = Point.of_cartesian(self.cable_def.width + 2 * self.insul_def.width,
                                     self.cable_def.thickness_i + 2 * self.insul_def.thickness)
             p4 = Point.of_cartesian(0.0, self.cable_def.thickness_i + 2 * self.insul_def.thickness)
-
-            area = Area.of_lines((Line.of_end_points(p1, p2),
-                                  Line.of_end_points(p2, p3),
-                                  Line.of_end_points(p3, p4),
-                                  Line.of_end_points(p4, p1)))
+            area = Area.of_closed_ordered_list_of_points(points=(p1, p2, p3, p4))
             area = area.rotate(self.block_def.alpha).translate(p_shift)
             self.areas.append(area)
 
@@ -93,7 +89,4 @@ class RectangularBlock(Block):
                                                       -self.insul_def.thickness).rotate(self.block_def.alpha)
         p4 = area.get_line(3).p1 + Point.of_cartesian(self.insul_def.width,
                                                       -self.insul_def.thickness).rotate(self.block_def.alpha)
-        return Area.of_lines((Line.of_end_points(p1, p2),
-                              Line.of_end_points(p2, p3),
-                              Line.of_end_points(p3, p4),
-                              Line.of_end_points(p4, p1)))
+        return Area.of_closed_ordered_list_of_points(points=(p1, p2, p3, p4))
