@@ -1,11 +1,10 @@
 import json
-from typing import List
+from typing import List, TypeVar
 
 import pandas as pd
 
 from magnumapi.geometry.roxie.CableDefinition import CableDefinition
 from magnumapi.geometry.roxie.ConductorDefinition import ConductorDefinition
-from magnumapi.geometry.roxie.Definition import Definition
 from magnumapi.geometry.roxie.FilamentDefinition import FilamentDefinition
 from magnumapi.geometry.roxie.InsulationDefinition import InsulationDefinition
 from magnumapi.geometry.roxie.QuenchDefinition import QuenchDefinition
@@ -15,8 +14,13 @@ from magnumapi.geometry.roxie.TransientDefinition import TransientDefinition
 import magnumapi.tool_adapters.roxie.RoxieAPI as RoxieAPI
 from magnumapi.tool_adapters.DirectoryManager import DirectoryManager
 
+T = TypeVar('T')
+
 
 class CableDatabase:
+    """ Class providing an interface to read, write, and access cable database definitions.
+
+    """
     keyword_to_class = {'INSUL': InsulationDefinition,
                         'REMFIT': RemFitDefinition,
                         'FILAMENT': FilamentDefinition,
@@ -34,7 +38,7 @@ class CableDatabase:
                  transient_defs: List[TransientDefinition],
                  quench_defs: List[QuenchDefinition],
                  cable_defs: List[CableDefinition],
-                 conductor_defs: List[ConductorDefinition]):
+                 conductor_defs: List[ConductorDefinition]) -> None:
 
         self.insul_defs = insul_defs
         self.remfit_defs = remfit_defs
@@ -46,7 +50,15 @@ class CableDatabase:
         self.conductor_defs = conductor_defs
 
     @classmethod
-    def initialize_definitions(cls, cadata_file_path: str, keyword: str) -> List[Definition]:
+    def initialize_definitions(cls, cadata_file_path: str, keyword: str) -> List[T]:
+        """ Method initializing a list of definitions of a given type from a given cadata file. Method reads a cadata
+        file and returns a dictionary, which is converted into a list of dictionaries. The list of dictionaries is
+        converted into a list of definitions.
+
+        :param cadata_file_path: a path to a cadata file
+        :param keyword: a cadata table name
+        :return: a list of cadata definitions for a given table name
+        """
         ClassDefinition = cls.keyword_to_class[keyword.upper()]
         try:
             df = RoxieAPI.read_bottom_header_table(cadata_file_path, keyword=keyword)
@@ -61,27 +73,53 @@ class CableDatabase:
         except IndexError:
             return [ClassDefinition(name='', comment='')]
 
-    def get_insul_definition(self, condname) -> InsulationDefinition:
+    def get_insul_definition(self, condname: str) -> InsulationDefinition:
+        """ Method returning an insulation definition for a given conductor name
+
+        :param condname: conductor name
+        :return: insulation definition if match, otherwise a KeyError is thrown
+        """
         insul_name = self.get_conductor_definition(condname).insulation
 
         return _find_matching_definition(self.insul_defs, insul_name, 'insulation')
 
-    def get_remfit_definition(self, condname) -> RemFitDefinition:
+    def get_remfit_definition(self, condname: str) -> RemFitDefinition:
+        """ Method returning a remfit definition for a given conductor name
+
+        :param condname: conductor name
+        :return: remfit definition if match, otherwise a KeyError is thrown
+        """
         remfit_name = self.get_filament_definition(condname).fit_perp
 
         return _find_matching_definition(self.remfit_defs, remfit_name, 'rem_fit')
 
-    def get_filament_definition(self, condname) -> FilamentDefinition:
+    def get_filament_definition(self, condname: str) -> FilamentDefinition:
+        """ Method returning a filament definition for a given conductor name
+
+        :param condname: conductor name
+        :return: filament definition if match, otherwise a KeyError is thrown
+        """
         filament_name = self.get_conductor_definition(condname).filament
 
         return _find_matching_definition(self.filament_defs, filament_name, 'filament')
 
-    def get_strand_definition(self, condname) -> StrandDefinition:
+    def get_strand_definition(self, condname: str) -> StrandDefinition:
+        """ Method returning a strand definition for a given conductor name
+
+        :param condname: conductor name
+        :return: strand definition if match, otherwise a KeyError is thrown
+        """
         strand_name = self.get_conductor_definition(condname).strand
 
         return _find_matching_definition(self.strand_defs, strand_name, 'strand')
 
-    def get_transient_definition(self, condname) -> TransientDefinition:
+    def get_transient_definition(self, condname: str) -> TransientDefinition:
+        """ Method returning a transient definition for a given conductor name. If there is no transient definition for
+        a given condname, then an empty transient definition is returned.
+
+        :param condname: conductor name
+        :return: transient definition if match, otherwise a KeyError is thrown
+        """
         trans_name = self.get_conductor_definition(condname).transient
 
         if trans_name == 'NONE':
@@ -89,7 +127,13 @@ class CableDatabase:
 
         return _find_matching_definition(self.transient_defs, trans_name, 'transient')
 
-    def get_quench_definition(self, condname) -> QuenchDefinition:
+    def get_quench_definition(self, condname: str) -> QuenchDefinition:
+        """ Method returning a quench definition for a given conductor name. If there is no quench definition for
+        a given condname, then an empty quench definition is returned.
+
+        :param condname: conductor name
+        :return: quench definition if match, otherwise a KeyError is thrown
+        """
         quench_name = self.get_conductor_definition(condname).quench_mat
 
         if quench_name == 'NONE':
@@ -97,16 +141,32 @@ class CableDatabase:
 
         return _find_matching_definition(self.quench_defs, quench_name, 'quench')
 
-    def get_cable_definition(self, condname) -> CableDefinition:
+    def get_cable_definition(self, condname: str) -> CableDefinition:
+        """ Method returning an insulation definition for a given conductor name
+
+        :param condname: conductor name
+        :return: insulation definition if match, otherwise a KeyError is thrown
+        """
         geometry_name = self.get_conductor_definition(condname).cable_geom
 
         return _find_matching_definition(self.cable_defs, geometry_name, 'cable')
 
-    def get_conductor_definition(self, condname) -> ConductorDefinition:
+    def get_conductor_definition(self, condname: str) -> ConductorDefinition:
+        """ Method returning an insulation definition for a given conductor name
+
+        :param condname: conductor name
+        :return: insulation definition if match, otherwise a KeyError is thrown
+        """
         return _find_matching_definition(self.conductor_defs, condname, 'conductor')
 
     @classmethod
     def read_json(cls, json_file_path: str) -> "CableDatabase":
+        """ Method reading a json file and returning an initialized CableDatabase instance. Some definitions are
+        optional. In this case, the
+
+        :param json_file_path: a path
+        :return: a CableDatabase instance with initialized lists of definitions
+        """
         with open(json_file_path) as json_file:
             data = json.load(json_file)
 
@@ -143,7 +203,10 @@ class CableDatabase:
                              conductor_defs=conductor_defs)
 
     def write_json(self, json_output_path: str) -> None:
+        """ Method writing a CableDatabase instance into a json file.
 
+        :param json_output_path: a path to an output json file
+        """
         json_cadata = {"insulation": self._get_insulation_definitions_as_list_of_dict(),
                        "remfit": self._get_remfit_definitions_as_list_of_dict(),
                        "filament": self._get_filament_definitions_as_list_of_dict(),
@@ -157,31 +220,68 @@ class CableDatabase:
             json.dump(json_cadata, f, ensure_ascii=False, indent=4)
 
     def _get_conductor_definitions_as_list_of_dict(self):
+        """ Method returning a list of conductor definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with conductor definitions sorted with ROXIE order
+        """
         return [ConductorDefinition.reorder_dct(conductor_def.__dict__) for conductor_def in self.conductor_defs]
 
     def _get_cable_definitions_as_list_of_dict(self):
+        """ Method returning a list of cable definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with cable definitions sorted with ROXIE order
+        """
         return [CableDefinition.reorder_dct(cable_def.__dict__) for cable_def in self.cable_defs]
 
     def _get_quench_definitions_as_list_of_dict(self):
+        """ Method returning a list of quench definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with quench definitions sorted with ROXIE order
+        """
         return [QuenchDefinition.reorder_dct(quench_def.__dict__) for quench_def in self.quench_defs]
 
     def _get_transient_definitions_as_list_of_dict(self):
+        """ Method returning a list of transient definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with transient definitions sorted with ROXIE order
+        """
         return [TransientDefinition.reorder_dct(transient_def.__dict__) for transient_def in self.transient_defs]
 
     def _get_strand_definitions_as_list_of_dict(self):
+        """ Method returning a list of strand definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with strand definitions sorted with ROXIE order
+        """
         return [StrandDefinition.reorder_dct(strand_def.__dict__) for strand_def in self.strand_defs]
 
     def _get_filament_definitions_as_list_of_dict(self):
+        """ Method returning a list of filament definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with filament definitions sorted with ROXIE order
+        """
         return [FilamentDefinition.reorder_dct(filament_def.__dict__) for filament_def in self.filament_defs]
 
     def _get_remfit_definitions_as_list_of_dict(self):
+        """ Method returning a list of remfit definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with remfit definitions sorted with ROXIE order
+        """
         return [RemFitDefinition.reorder_dct(remfit_def.__dict__) for remfit_def in self.remfit_defs]
 
     def _get_insulation_definitions_as_list_of_dict(self):
+        """ Method returning a list of insulation definitions as a list of dictionaries sorted with ROXIE order.
+
+        :return: a list of dictionaries with insulation definitions sorted with ROXIE order
+        """
         return [InsulationDefinition.reorder_dct(insul_def.__dict__) for insul_def in self.insul_defs]
 
     @classmethod
-    def read_cadata(cls, cadata_file_path):
+    def read_cadata(cls, cadata_file_path: str) -> "CableDatabase":
+        """ Method reading a cadata file and returns an initialized CableDatabase instance with a list of definitions.
+
+        :param cadata_file_path: a path to a cadata file
+        :return: a CableDatabase instance with initialized lists of definitions
+        """
         DirectoryManager.check_if_file_exists(cadata_file_path)
 
         return CableDatabase(insul_defs=cls.initialize_definitions(cadata_file_path, keyword='INSUL'),
@@ -194,15 +294,19 @@ class CableDatabase:
                              conductor_defs=cls.initialize_definitions(cadata_file_path, keyword='CONDUCTOR'))
 
     def write_cadata(self, cadata_output_path: str) -> None:
+        """ Method writing a CableDatabase instance into a cadata file.
+
+        :param cadata_output_path: a path to an output cadata file
+        """
         output = ['VERSION 11',
-                  self._convert_definitions_df_to_bottom_header_str(self.get_insul_df(), 'INSUL'),
-                  self._convert_definitions_df_to_bottom_header_str(self.get_remfit_df(), 'REMFIT'),
-                  self._convert_definitions_df_to_bottom_header_str(self.get_filament_df(), 'FILAMENT'),
-                  self._convert_definitions_df_to_bottom_header_str(self.get_strand_df(), 'STRAND'),
-                  self._convert_definitions_df_to_bottom_header_str(self.get_transient_df(), 'TRANSIENT'),
-                  self._convert_definitions_df_to_bottom_header_str(self.get_quench_df(), 'QUENCH'),
-                  self._convert_definitions_df_to_bottom_header_str(self.get_cable_df(), 'CABLE'),
-                  self._convert_definitions_df_to_bottom_header_str(self.get_conductor_df(), 'CONDUCTOR')
+                  self._convert_definition_df_to_bottom_header_str(self.get_insul_df(), 'INSUL'),
+                  self._convert_definition_df_to_bottom_header_str(self.get_remfit_df(), 'REMFIT'),
+                  self._convert_definition_df_to_bottom_header_str(self.get_filament_df(), 'FILAMENT'),
+                  self._convert_definition_df_to_bottom_header_str(self.get_strand_df(), 'STRAND'),
+                  self._convert_definition_df_to_bottom_header_str(self.get_transient_df(), 'TRANSIENT'),
+                  self._convert_definition_df_to_bottom_header_str(self.get_quench_df(), 'QUENCH'),
+                  self._convert_definition_df_to_bottom_header_str(self.get_cable_df(), 'CABLE'),
+                  self._convert_definition_df_to_bottom_header_str(self.get_conductor_df(), 'CONDUCTOR')
                   ]
 
         # Write to a text file
@@ -211,7 +315,13 @@ class CableDatabase:
                 file_write.write(output_el + '\n\n')
 
     @classmethod
-    def _convert_definitions_df_to_bottom_header_str(cls, df: pd.DataFrame, keyword: str) -> str:
+    def _convert_definition_df_to_bottom_header_str(cls, df: pd.DataFrame, keyword: str) -> str:
+        """ Method converting a definition dataframe to a string representation as a bottom header table for ROXIE.
+
+        :param df: input dataframe with definitions
+        :param keyword: name of a table
+        :return: a string formatted as a bottom header table of ROXIE
+        """
         # Get the definition class
         ClassDefinition = cls.keyword_to_class[keyword.upper()]
         # Convert to a dataframe
@@ -228,40 +338,80 @@ class CableDatabase:
         # Convert a dataframe to a bottom header table
         return RoxieAPI.convert_bottom_header_table_to_str(df, keyword=keyword)
 
-    def get_insul_df(self):
+    def get_insul_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with insulation definitions.
+
+        :return: a dataframe table with insulation definitions.
+        """
         insulation_definitions = self._get_insulation_definitions_as_list_of_dict()
         return pd.DataFrame(insulation_definitions)
 
-    def get_remfit_df(self):
+    def get_remfit_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with remfit definitions.
+
+        :return: a dataframe table with remfit definitions.
+        """
         remfit_definitions = self._get_remfit_definitions_as_list_of_dict()
         return pd.DataFrame(remfit_definitions)
 
-    def get_filament_df(self):
+    def get_filament_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with filament definitions.
+
+        :return: a dataframe table with filament definitions.
+        """
         filament_definitions = self._get_filament_definitions_as_list_of_dict()
         return pd.DataFrame(filament_definitions)
 
-    def get_strand_df(self):
+    def get_strand_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with strand definitions.
+
+        :return: a dataframe table with strand definitions.
+        """
         strand_definitions = self._get_strand_definitions_as_list_of_dict()
         return pd.DataFrame(strand_definitions)
 
-    def get_transient_df(self):
+    def get_transient_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with transient definitions.
+
+        :return: a dataframe table with transient definitions.
+        """
         transient_definitions = self._get_transient_definitions_as_list_of_dict()
         return pd.DataFrame(transient_definitions)
 
-    def get_quench_df(self):
+    def get_quench_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with quench definitions.
+
+        :return: a dataframe table with quench definitions.
+        """
         quench_definitions = self._get_quench_definitions_as_list_of_dict()
         return pd.DataFrame(quench_definitions)
 
-    def get_cable_df(self):
+    def get_cable_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with cable definitions.
+
+        :return: a dataframe table with cable definitions.
+        """
         cable_definitions = self._get_cable_definitions_as_list_of_dict()
         return pd.DataFrame(cable_definitions)
 
-    def get_conductor_df(self):
+    def get_conductor_df(self) -> pd.DataFrame:
+        """ Method returning a dataframe table with conductor definitions.
+
+        :return: a dataframe table with conductor definitions.
+        """
         conductor_definitions = self._get_conductor_definitions_as_list_of_dict()
         return pd.DataFrame(conductor_definitions)
 
 
-def _find_matching_definition(defs, name_def, desc_def):
+def _find_matching_definition(defs: List[T], name_def: str, desc_def: str) -> T:
+    """ Function finding a definition with a matching name in a list of input definitions. If there is a match, then
+    the definition is returned, otherwise a KeyError is thrown.
+
+    :param defs: list of input definitions over which a search is performed.
+    :param name_def: name of a definition to find.
+    :param desc_def: name of a key storing the definition name.
+    :return: If there is a match, then the definition is returned, otherwise a KeyError is thrown.
+    """
     matches = list(filter(lambda x: x.name == name_def, defs))
 
     if matches:
