@@ -5,4 +5,9 @@ from magnumapi.geometry.roxie.BlockDefinition import BlockDefinition
 
 @dataclass
 class CosThetaBlockDefinition(BlockDefinition):
+    """Class for cos-theta block definition.
+
+    Attributes:
+       radius (float): The radius in millimeter.
+    """
     radius: float
