@@ -9,15 +9,12 @@ import numpy as np
 import pandas as pd
 from IPython.display import display
 
-import magnumapi.optimization.NotebookConverter as NotebookConverter
 from magnumapi.optimization.DesignVariable import GeneticDesignVariable
 from magnumapi.optimization.Logger import Logger
 from magnumapi.optimization.ModelExecutor import ModelExecutorFactory
-from magnumapi.optimization.ObjectiveConfig import ObjectiveConfig
 from magnumapi.optimization.OptimizationConfig import OptimizationConfig
 from magnumapi.optimization.OptimizationNotebookConfig import OptimizationNotebookConfig
 from magnumapi.optimization.constants import PENALTY, ERROR_KEY
-from magnumapi.tool_adapters.DirectoryManager import DirectoryManager
 
 T = TypeVar('T')
 
@@ -163,33 +160,7 @@ class GeneticOptimization(Optimization, ABC):
 
     @staticmethod
     def initialize_config(json_path: str) -> OptimizationConfig:
-        """ Method initializing an optimization config from a json file
-
-        :param json_path: a path to a json file with config
-        :return: initialized OptimizationConfig instance
-        """
-        with open(json_path) as f:
-            data = json.load(f)
-
-        input_folder = data['input_folder']
-        output_folder = data['output_folder']
-        logger_rel_path = data['logger_rel_path']
-        n_pop = data['n_pop']
-        n_gen = data['n_gen']
-        r_cross = data['r_cross']
-        r_mut = data['r_mut']
-        objectives = [ObjectiveConfig(**ff) for ff in data['objectives']]
-        notebooks = [OptimizationNotebookConfig(**nb) for nb in data['notebooks']]
-
-        return OptimizationConfig(input_folder=input_folder,
-                                  output_folder=output_folder,
-                                  logger_rel_path=logger_rel_path,
-                                  n_pop=n_pop,
-                                  n_gen=n_gen,
-                                  r_cross=r_cross,
-                                  r_mut=r_mut,
-                                  objectives=objectives,
-                                  notebooks=notebooks)
+        return OptimizationConfig.initialize_config(json_path)
 
     def calculate_score(self, fom_dct: Dict[str, float]) -> float:
         """ Method calculating score from a dictionary mapping objective variable to its value.
@@ -396,6 +367,7 @@ class RoxieGeneticOptimization(GeneticOptimization):
         :param individual: a list of 0s and 1s representing an individual to be executed
         :return: a dictionary with figures of merit if the computation was successful, otherwise an dictionary with NaNs
         """
+        # ToDo: Move to ModelExecutor
         # Retrieve global parameters
         decoded_chromosome = self.decode_individual(individual)
         global_design_variables = {key: value for (key, value) in decoded_chromosome.items() if ':' not in key}
@@ -447,36 +419,3 @@ class RoxieGeneticOptimization(GeneticOptimization):
             elif source in global_design_variables.keys():
                 parameters_dct[dest] = global_design_variables[source]
         return parameters_dct
-
-
-def initialize_folder_structure(config) -> str:
-    """ Method initializing the folder directory structure to store optimization results outside of the main
-    directory.
-
-    :return: a path to the output root directory where all results are stored.
-    """
-    DirectoryManager.create_directory_if_nonexistent(config.output_folder)
-    subdirectory_name = DirectoryManager.find_output_subdirectory_name(config.output_folder)
-    output_subdirectory_dir = os.path.join(config.output_folder, subdirectory_name)
-
-    DirectoryManager.create_directory_if_nonexistent(output_subdirectory_dir)
-    DirectoryManager.copy_model_input(config.input_folder, 'input', output_subdirectory_dir)
-    DirectoryManager.copy_notebook_folders(config.input_folder, config.notebooks, output_subdirectory_dir)
-    DirectoryManager.create_directory_if_nonexistent(os.path.join(output_subdirectory_dir, 'optimization'))
-    DirectoryManager.copy_model_input(config.input_folder, 'optimization', output_subdirectory_dir)
-
-    logger_path = os.path.join(output_subdirectory_dir, config.logger_rel_path)
-    print('The logger is saved in: %s' % logger_path)
-
-    for config_notebook in config.notebooks:
-        input_ipynb_file_path = os.path.join(output_subdirectory_dir,
-                                             config_notebook.notebook_folder,
-                                             config_notebook.notebook_name)
-        output_ipynb_file_path = os.path.join(output_subdirectory_dir,
-                                              config_notebook.notebook_folder,
-                                              config_notebook.notebook_name.lower().replace('.ipynb', '.py'))
-        NotebookConverter.convert_notebook_to_script(input_ipynb_file_path,
-                                                     config_notebook.notebook_name.lower().split('.')[0],
-                                                     output_ipynb_file_path)
-
-    return output_subdirectory_dir
