@@ -102,6 +102,6 @@ class OptimizationCockpit:
         logger_new_df = pd.read_csv(self.logger_abs_path, index_col=0)
         if len(logger_new_df) > len(self.logger_df):
             self.logger_df = logger_new_df
-            self.widget.min_logger_df = Logger.extract_min_rows_from_logger_df(self.logger_df)
+            self.widget.min_logger_df = Logger.extract_min_rows_from_logger_df(self.logger_df, self.config.n_pop)
             self.widget.widget.data = []
             self.widget.build()
