@@ -9,6 +9,10 @@ print('Loaded Tool Adapter version 0.0.1 for ANSYS2020R2')
 
 
 class AnsysToolAdapter(ToolAdapter):
+    """ An AnsysToolAdapter class with methods to execute an ANSYS model from command line, read figures of merit table
+    and prepare a Lorentz force file
+
+    """
 
     def __init__(self,
                  ansys_path: str,
@@ -17,6 +21,14 @@ class AnsysToolAdapter(ToolAdapter):
                  out_path: str,
                  output_file: str
                  ) -> None:
+        """ A constructor of AnsysToolAdapter instance
+
+        :param ansys_path: a path to an ansys executable
+        :param rel_dir: a relative directory with model
+        :param inp_path: a path to an input file
+        :param out_path: a path to an output file
+        :param output_file: a path to an output file #ToDo: is it a path or a name?
+        """
         self.ansys_path = ansys_path
         self.rel_dir = rel_dir
         self.inp_path = inp_path
@@ -29,12 +41,11 @@ class AnsysToolAdapter(ToolAdapter):
             os.remove(self.output_file)
         else:  ## Show an error ##
             print("Warning: %s file not found" % self.output_file)
-
-        p = Popen([self.ansys_path, '-b', '-p', '-aa_r', '-smp', '-np', '2', '-lch', '-dir', self.rel_dir, '-i',
-                   self.inp_path, '-o', self.out_path],
-                  stdin=PIPE, stdout=PIPE, stderr=PIPE)
+        # ToDo: -aa_r should come as a parameter
+        cmd = [self.ansys_path, '-b', '-p', '-aa_r', '-smp', '-np', '2', '-lch', '-dir', self.rel_dir, '-i',
+                 self.inp_path, '-o', self.out_path]
+        p = Popen(cmd, stdin=PIPE, stdout=PIPE, stderr=PIPE)
         byte_output, err = p.communicate(b"input data that is passed to subprocess' stdin")
-        rc = p.returncode
 
         byte_output_decode = byte_output.decode()
         self.output_lines = byte_output_decode.split('\n')
@@ -57,7 +68,12 @@ class AnsysToolAdapter(ToolAdapter):
         return fom_df.to_dict('records')[0]
 
     @staticmethod
-    def prepare_force_file(force_input_path, force_output_path):
+    def prepare_force_file(force_input_path: str, force_output_path: str) -> None:
+        """ Method preparing a force file for ANSYS from a ROXIE Lorentz force file, .force2d
+
+        :param force_input_path: an path to a ROXIE Lorentz force file
+        :param force_output_path: a path to an output file for ANSYS
+        """
         with open(force_input_path, 'r') as file_read:
             force_txt = file_read.readlines()
 
