@@ -57,8 +57,8 @@ class RoxieInputBuilder:
         with open(template_path, 'r') as template_file:
             template_content = template_file.read()
 
-        with open(output_path, 'w') as input_file:
-            input_file.write(template_content.format(output_str))
+        with open(output_path, 'wb') as input_file:
+            input_file.write(bytes(template_content.format(output_str), 'utf-8').replace(b'\r\n', b'\n'))
 
     def prepare_data_file_str(self) -> str:
         """ Method preparing a data file string content
