@@ -1,6 +1,5 @@
 from unittest import TestCase
 from unittest.mock import patch
-from io import StringIO
 
 import matplotlib.pyplot as plt
 
@@ -1121,3 +1120,57 @@ class TestCosThetaBlock(TestCase):
             cos_theta_block.to_roxie_df()
 
         self.assertTrue('This method is not implemented for this class' in str(context.exception))
+
+    def test_calculate_radiality_alpha_correction_index_error(self):
+        # arrange
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=10.0, nco=1, condname='16TIL6E',
+                                                        no=1, current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
+        block = RelativeCosThetaBlock(block_def=block_rel_def,
+                                      cable_def=self.cadata.get_cable_definition('16TIL6E'),
+                                      insul_def=self.cadata.get_insul_definition('16TIL6E'),
+                                      strand_def=self.cadata.get_strand_definition('16TIL6E'),
+                                      conductor_def=self.cadata.get_conductor_definition('16TIL6E'))
+
+        # act
+        # assert
+        with self.assertRaises(IndexError) as context:
+            CosThetaBlock.calculate_radiality_alpha_correction(block)
+
+        exception_message = 'The list of areas is empty, please build block first with build_block() method.'
+        self.assertTrue(exception_message in str(context.exception))
+
+    def test_calculate_radiality_alpha_correction_single_turn(self):
+        # arrange
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=10.0, nco=1, condname='16TIL6E',
+                                                        no=1, current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
+        block = RelativeCosThetaBlock(block_def=block_rel_def,
+                                      cable_def=self.cadata.get_cable_definition('16TIL6E'),
+                                      insul_def=self.cadata.get_insul_definition('16TIL6E'),
+                                      strand_def=self.cadata.get_strand_definition('16TIL6E'),
+                                      conductor_def=self.cadata.get_conductor_definition('16TIL6E'))
+
+        # act
+        block.build_block()
+
+        # assert
+        alpha_correction = CosThetaBlock.calculate_radiality_alpha_correction(block)
+
+        self.assertAlmostEqual(-2.99267610, alpha_correction, places=7)
+
+    def test_calculate_radiality_alpha_correction_five_turns(self):
+        # arrange
+        block_rel_def = RelativeCosThetaBlockDefinition(radius=25, phi_r=5.0, alpha_r=10.0, nco=5, condname='16TIL6E',
+                                                        no=1, current=13500, type=1, n1=2, n2=20, imag=0, turn=0)
+        block = RelativeCosThetaBlock(block_def=block_rel_def,
+                                      cable_def=self.cadata.get_cable_definition('16TIL6E'),
+                                      insul_def=self.cadata.get_insul_definition('16TIL6E'),
+                                      strand_def=self.cadata.get_strand_definition('16TIL6E'),
+                                      conductor_def=self.cadata.get_conductor_definition('16TIL6E'))
+
+        # act
+        block.build_block()
+
+        # assert
+        alpha_correction = CosThetaBlock.calculate_radiality_alpha_correction(block)
+
+        self.assertAlmostEqual(4.93033090, alpha_correction, places=7)
