@@ -1,6 +1,5 @@
 import unittest
 from unittest.mock import patch
-from io import StringIO
 
 import pandas as pd
 
@@ -1122,3 +1121,28 @@ class CosThetaGeometryTest(unittest.TestCase):
         self.assertEqual(100, rrr)
         self.assertAlmostEqual(1.1, d_strand, places=2)
         self.assertEqual(22, n_s)
+
+    @patch("plotly.graph_objects.Figure.show")
+    def test_with_roxie_absolute_angle_definition_json_radiality_corection(self, mock_show=None):
+        # arrange
+        json_path = create_resources_file_path('resources/geometry/roxie/16T/16T_abs.json')
+        cadata_path = create_resources_file_path('resources/geometry/roxie/16T/roxieold_2.cadata')
+        cadata = CableDatabase.read_cadata(cadata_path)
+
+        # act
+        geometry = GeometryFactory.init_with_json(json_path, cadata)
+
+        geometry.build_blocks()
+        geometry.plotly_blocks(figsize=(90, 90), xlim=(0, 85))
+
+        geometry.correct_radiality()
+
+        # Build corrected blocks
+        geometry.build_blocks()
+
+        # Display corrected blocks
+        geometry.plotly_blocks(figsize=(90, 90), xlim=(0, 85))
+
+        # assert
+        if mock_show is not None:
+            mock_show.assert_called()
